document.querySelectorAll('input[name="mode"]').forEach(input => input.addEventListener('change', updateMode));
document.getElementById('website-type').addEventListener('change', updateOptions);
document.getElementById('original-website-type').addEventListener('change', updateRevisionOptions);
document.getElementById('pricing-form').addEventListener('change', calculatePrice);
document.getElementById('save-btn').addEventListener('click', saveToJson);
document.getElementById('currency').addEventListener('change', calculatePrice);

// Website type configurations (for new projects)
const websiteConfigs = {
    personal: { pages: true, design: ['template', 'custom-design'], preSelectedDesign: 'template', features: ['contact-form', 'seo', 'animations'], preSelectedFeatures: [], content: true, maintenance: true },
    blog: { pages: true, design: ['template', 'custom-design'], preSelectedDesign: 'template', features: ['blog-cms', 'seo', 'contact-form'], preSelectedFeatures: ['blog-cms'], content: true, maintenance: true },
    'small-business': { pages: true, design: ['template', 'custom-design'], preSelectedDesign: 'template', features: ['contact-form', 'seo', 'animations', 'integrations'], preSelectedFeatures: [], content: true, maintenance: true },
    ecommerce: { pages: true, design: ['template', 'custom-design'], preSelectedDesign: 'custom-design', features: ['ecommerce-features', 'user-accounts', 'seo', 'search', 'contact-form', 'integrations'], preSelectedFeatures: [], content: true, maintenance: true },
    'custom-app': { pages: true, design: ['custom-design'], preSelectedDesign: 'custom-design', features: ['user-accounts', 'integrations', 'search', 'animations', 'seo'], preSelectedFeatures: [], content: true, maintenance: true },
    'non-profit': { pages: true, design: ['template', 'custom-design'], preSelectedDesign: 'template', features: ['contact-form', 'seo', 'integrations', 'animations'], preSelectedFeatures: [], content: true, maintenance: true },
    'education-lms': { pages: true, design: ['template', 'custom-design'], preSelectedDesign: 'custom-design', features: ['user-accounts', 'integrations', 'search', 'seo', 'animations'], preSelectedFeatures: ['user-accounts'], content: true, maintenance: true },
    membership: { pages: true, design: ['template', 'custom-design'], preSelectedDesign: 'custom-design', features: ['user-accounts', 'integrations', 'seo', 'search', 'animations'], preSelectedFeatures: ['user-accounts'], content: true, maintenance: true },
    'real-estate': { pages: true, design: ['template', 'custom-design'], preSelectedDesign: 'template', features: ['search', 'contact-form', 'seo', 'integrations', 'animations'], preSelectedFeatures: ['search'], content: true, maintenance: true },
    'creative-portfolio': { pages: true, design: ['template', 'custom-design'], preSelectedDesign: 'custom-design', features: ['animations', 'contact-form', 'seo'], preSelectedFeatures: ['animations'], content: true, maintenance: true },
    event: { pages: true, design: ['template', 'custom-design'], preSelectedDesign: 'template', features: ['contact-form', 'integrations', 'seo', 'animations'], preSelectedFeatures: [], content: true, maintenance: true },
    directory: { pages: true, design: ['template', 'custom-design'], preSelectedDesign: 'custom-design', features: ['search', 'user-accounts', 'seo', 'integrations', 'animations'], preSelectedFeatures: ['search'], content: true, maintenance: true },
    'landing-page': { pages: false, design: ['template', 'custom-design'], preSelectedDesign: 'template', features: ['contact-form', 'seo', 'animations'], preSelectedFeatures: [], content: true, maintenance: true }
};

// Revision configurations (for revisions & updates)
const revisionConfigs = {
    personal: { revisions: ['text-updates', 'image-swaps', 'css-tweaks', 'redesign-sections', 'update-branding', 'seo-updates', 'security-updates', 'performance-optimization', 'accessibility-improvements', 'backup-migration', 'add-contact-form', 'add-animations', 'add-new-pages'] },
    blog: { revisions: ['text-updates', 'image-swaps', 'css-tweaks', 'redesign-sections', 'update-branding', 'seo-updates', 'security-updates', 'performance-optimization', 'accessibility-improvements', 'backup-migration', 'add-contact-form', 'add-blog-cms', 'add-new-pages'] },
    'small-business': { revisions: ['text-updates', 'image-swaps', 'css-tweaks', 'redesign-sections', 'update-branding', 'seo-updates', 'security-updates', 'performance-optimization', 'accessibility-improvements', 'backup-migration', 'add-contact-form', 'add-animations', 'add-integrations', 'add-new-pages'] },
    ecommerce: { revisions: ['text-updates', 'image-swaps', 'css-tweaks', 'redesign-sections', 'update-branding', 'seo-updates', 'security-updates', 'performance-optimization', 'accessibility-improvements', 'backup-migration', 'add-contact-form', 'add-ecommerce', 'add-user-accounts', 'add-search', 'add-integrations', 'add-new-pages'] },
    'custom-app': { revisions: ['text-updates', 'image-swaps', 'css-tweaks', 'redesign-sections', 'update-branding', 'seo-updates', 'security-updates', 'performance-optimization', 'accessibility-improvements', 'backup-migration', 'add-user-accounts', 'add-search', 'add-integrations', 'add-animations', 'add-new-pages'] },
    'non-profit': { revisions: ['text-updates', 'image-swaps', 'css-tweaks', 'redesign-sections', 'update-branding', 'seo-updates', 'security-updates', 'performance-optimization', 'accessibility-improvements', 'backup-migration', 'add-contact-form', 'add-integrations', 'add-animations', 'add-new-pages'] },
    'education-lms': { revisions: ['text-updates', 'image-swaps', 'css-tweaks', 'redesign-sections', 'update-branding', 'seo-updates', 'security-updates', 'performance-optimization', 'accessibility-improvements', 'backup-migration', 'add-user-accounts', 'add-search', 'add-integrations', 'add-animations', 'add-new-pages'] },
    membership: { revisions: ['text-updates', 'image-swaps', 'css-tweaks', 'redesign-sections', 'update-branding', 'seo-updates', 'security-updates', 'performance-optimization', 'accessibility-improvements', 'backup-migration', 'add-user-accounts', 'add-search', 'add-integrations', 'add-animations', 'add-new-pages'] },
    'real-estate': { revisions: ['text-updates', 'image-swaps', 'css-tweaks', 'redesign-sections', 'update-branding', 'seo-updates', 'security-updates', 'performance-optimization', 'accessibility-improvements', 'backup-migration', 'add-contact-form', 'add-search', 'add-integrations', 'add-animations', 'add-new-pages'] },
    'creative-portfolio': { revisions: ['text-updates', 'image-swaps', 'css-tweaks', 'redesign-sections', 'update-branding', 'seo-updates', 'security-updates', 'performance-optimization', 'accessibility-improvements', 'backup-migration', 'add-contact-form', 'add-animations', 'add-new-pages'] },
    event: { revisions: ['text-updates', 'image-swaps', 'css-tweaks', 'redesign-sections', 'update-branding', 'seo-updates', 'security-updates', 'performance-optimization', 'accessibility-improvements', 'backup-migration', 'add-contact-form', 'add-integrations', 'add-animations', 'add-new-pages'] },
    directory: { revisions: ['text-updates', 'image-swaps', 'css-tweaks', 'redesign-sections', 'update-branding', 'seo-updates', 'security-updates', 'performance-optimization', 'accessibility-improvements', 'backup-migration', 'add-user-accounts', 'add-search', 'add-integrations', 'add-animations', 'add-new-pages'] },
    'landing-page': { revisions: ['text-updates', 'image-swaps', 'css-tweaks', 'redesign-sections', 'update-branding', 'seo-updates', 'security-updates', 'performance-optimization', 'accessibility-improvements', 'backup-migration', 'add-contact-form', 'add-animations'] }
};

// Base prices for website types (for new projects, in USD)
const basePrices = {
    personal: { min: 1000, max: 3000, baseTime: 2 * 5 },
    blog: { min: 1500, max: 4000, baseTime: 3 * 5 },
    'small-business': { min: 3000, max: 8000, baseTime: 4 * 5 },
    ecommerce: { min: 5000, max: 20000, baseTime: 8 * 5 },
    'custom-app': { min: 15000, max: 75000, baseTime: 12 * 5 },
    'non-profit': { min: 2000, max: 6000, baseTime: 4 * 5 },
    'education-lms': { min: 8000, max: 25000, baseTime: 10 * 5 },
    membership: { min: 5000, max: 15000, baseTime: 8 * 5 },
    'real-estate': { min: 4000, max: 12000, baseTime: 6 * 5 },
    'creative-portfolio': { min: 3000, max: 10000, baseTime: 5 * 5 },
    event: { min: 3000, max: 8000, baseTime: 4 * 5 },
    directory: { min: 6000, max: 18000, baseTime: 8 * 5 },
    'landing-page': { min: 800, max: 2500, baseTime: 1 * 5 }
};

// Feature prices (for new projects, in USD)
const featurePrices = {
    'contact-form': { min: 150, max: 400, time: 0.5 * 5 },
    'blog-cms': { min: 800, max: 2000, time: 1 * 5 },
    'ecommerce-features': { min: 1000, max: 5000, time: 2 * 5 },
    'user-accounts': { min: 800, max: 3000, time: 1 * 5 },
    search: { min: 400, max: 1000, time: 0.5 * 5 },
    animations: { min: 800, max: 3000, time: 1 * 5 },
    seo: { min: 500, max: 1500, time: 1 * 5 },
    integrations: { min: 800, max: 3000, time: 1 * 5 }
};

// Revision prices (for revisions & updates, in hours)
const revisionPrices = {
    'text-updates': { minTime: 0.5, maxTime: 1, perPage: true },
    'image-swaps': { minTime: 0.5, maxTime: 1, perItem: true },
    'css-tweaks': { minTime: 1, maxTime: 2, perItem: true },
    'redesign-sections': { minTime: 2, maxTime: 5, perItem: true },
    'update-branding': { minTime: 5, maxTime: 10, perItem: false },
    'add-contact-form': { minTime: 2, maxTime: 5, perItem: false },
    'add-blog-cms': { minTime: 5, maxTime: 15, perItem: false },
    'add-ecommerce': { minTime: 20, maxTime: 50, perItem: false },
    'add-user-accounts': { minTime: 5, maxTime: 15, perItem: false },
    'add-search': { minTime: 5, maxTime: 10, perItem: false },
    'add-animations': { minTime: 2, maxTime: 5, perItem: true },
    'add-integrations': { minTime: 5, maxTime: 15, perItem: false },
    'seo-updates': { minTime: 2, maxTime: 5, perItem: false },
    'security-updates': { minTime: 1, maxTime: 3, perItem: false },
    'performance-optimization': { minTime: 2, maxTime: 5, perItem: false },
    'accessibility-improvements': { minTime: 3, maxTime: 8, perItem: false },
    'backup-migration': { minTime: 2, maxTime: 5, perItem: false },
    'add-new-pages': { minTime: 2, maxTime: 5, perPage: true }
};

// Currency configurations (approximate exchange rates as of March 2025)
const currencyConfigs = {
    USD: { symbol: '$', rate: 1 },
    EUR: { symbol: '€', rate: 0.92 },
    GBP: { symbol: '£', rate: 0.78 },
    INR: { symbol: '₹', rate: 85 },
    AUD: { symbol: 'A$', rate: 1.52 }, // 1 USD = 1.52 AUD
    AFN: { symbol: 'AF', rate: 70 }    // 1 USD = 70 AFN
};

const HOURLY_RATE = 100; // Base hourly rate in USD
const HOURS_PER_DAY = 8;

document.getElementById('hourly-rate-text').textContent = `Hourly Rate: ${currencyConfigs.USD.symbol}${HOURLY_RATE}/hour`;

function updateMode() {
    const mode = document.querySelector('input[name="mode"]:checked').value;
    const isNewProject = mode === 'new-project';

    document.getElementById('new-project-sections').style.display = isNewProject ? 'block' : 'none';
    document.getElementById('revisions-sections').style.display = isNewProject ? 'none' : 'block';

    if (isNewProject) updateOptions();
    else updateRevisionOptions();

    calculatePrice();
}

function updateOptions() {
    const websiteType = document.getElementById('website-type').value;
    const config = websiteConfigs[websiteType];

    document.querySelectorAll('input[name="features"]').forEach(input => {
        input.checked = false;
        input.parentElement.classList.remove('disabled-feature');
    });
    document.querySelectorAll('input[name="design"]').forEach(input => {
        input.checked = false;
        input.disabled = false;
    });
    document.querySelectorAll('input[name="content"]').forEach(input => {
        input.checked = input.value === 'no-content';
    });
    document.getElementById('branding').checked = false;
    document.getElementById('hosting').checked = false;
    document.getElementById('maintenance').checked = false;

    document.getElementById('pages-section').style.display = config.pages ? 'block' : 'none';
    document.getElementById('pages').value = config.pages ? 1 : 1;

    document.getElementById('template').disabled = !config.design.includes('template');
    document.getElementById('custom-design').disabled = !config.design.includes('custom-design');
    document.querySelector(`input[name="design"][value="${config.preSelectedDesign}"]`).checked = true;

    document.querySelectorAll('input[name="features"]').forEach(input => {
        const feature = input.value;
        if (!config.features.includes(feature)) input.parentElement.classList.add('disabled-feature');
        else input.parentElement.classList.remove('disabled-feature');
        if (config.preSelectedFeatures.includes(feature)) input.checked = true;
    });

    document.getElementById('content-section').style.display = config.content ? 'block' : 'none';
    document.getElementById('maintenance-section').style.display = config.maintenance ? 'block' : 'none';

    calculatePrice();
}

function updateRevisionOptions() {
    const websiteType = document.getElementById('original-website-type').value;
    const config = revisionConfigs[websiteType];
    const currency = document.getElementById('currency').value;
    const currencyConfig = currencyConfigs[currency];
    document.getElementById('hourly-rate-text').textContent = `Hourly Rate: ${currencyConfig.symbol}${Math.round(HOURLY_RATE * currencyConfig.rate)}/hour`;

    document.querySelectorAll('input[name="revisions"]').forEach(input => {
        input.checked = false;
        input.parentElement.classList.remove('disabled-feature');
    });
    document.getElementById('items-to-update').value = 0;

    document.querySelectorAll('input[name="revisions"]').forEach(input => {
        const revision = input.value;
        if (!config.revisions.includes(revision)) input.parentElement.classList.add('disabled-feature');
        else input.parentElement.classList.remove('disabled-feature');
    });

    const pagesInput = document.getElementById('pages-to-update');
    if (websiteType === 'landing-page') {
        pagesInput.value = 1;
        pagesInput.disabled = true;
    } else {
        pagesInput.value = 0;
        pagesInput.disabled = false;
    }

    calculatePrice();
}

function calculatePrice() {
    const mode = document.querySelector('input[name="mode"]:checked').value;
    const timeline = document.getElementById('timeline').value;
    const currency = document.getElementById('currency').value;
    const currencyConfig = currencyConfigs[currency];

    let results = {};

    if (mode === 'new-project') {
        const websiteType = document.getElementById('website-type').value;
        const config = websiteConfigs[websiteType];
        const pages = config.pages ? parseInt(document.getElementById('pages').value) || 1 : 1;
        const design = document.querySelector('input[name="design"]:checked')?.value || config.preSelectedDesign;
        const branding = document.getElementById('branding').checked;
        const features = Array.from(document.querySelectorAll('input[name="features"]:checked')).map(f => f.value).filter(f => config.features.includes(f));
        const content = document.querySelector('input[name="content"]:checked')?.value || 'no-content';
        const hosting = document.getElementById('hosting').checked;
        const maintenance = document.getElementById('maintenance').checked;

        let minPrice = basePrices[websiteType].min;
        let maxPrice = basePrices[websiteType].max;
        let baseTime = basePrices[websiteType].baseTime;

        const extraPages = pages > 5 ? (pages - 5) * 200 : 0;
        const extraPagesMax = pages > 5 ? (pages - 5) * 500 : 0;
        minPrice += extraPages;
        maxPrice += extraPagesMax;
        baseTime += pages > 5 ? (pages - 5) * 0.5 * 5 : 0;

        if (design === 'custom-design') {
            minPrice += 2000;
            maxPrice += 7000;
            baseTime += 2 * 5;
        } else {
            minPrice += 500;
            maxPrice += 1500;
        }

        if (branding) {
            minPrice += 800;
            maxPrice += 3000;
            baseTime += 1 * 5;
        }

        features.forEach(feature => {
            minPrice += featurePrices[feature].min;
            maxPrice += featurePrices[feature].max;
            baseTime += featurePrices[feature].time;
        });

        if (content === 'copywriting') {
            minPrice += pages * 75;
            maxPrice += pages * 200;
            baseTime += pages * 0.25 * 5;
        } else if (content === 'media') {
            minPrice += 300;
            maxPrice += 1500;
            baseTime += 1 * 5;
        }

        let monthlyMaintenanceMin = 0;
        let monthlyMaintenanceMax = 0;
        if (hosting) {
            minPrice += 150;
            maxPrice += 600;
            baseTime += 0.5 * 5;
        }
        if (maintenance) {
            monthlyMaintenanceMin = 75;
            monthlyMaintenanceMax = 400;
        }

        let finalTime = timeline === 'rush' ? baseTime / 2 : baseTime;
        if (timeline === 'rush') {
            minPrice *= 1.25;
            maxPrice *= 1.5;
            monthlyMaintenanceMin *= 1.25;
            monthlyMaintenanceMax *= 1.5;
        }

        minPrice *= currencyConfig.rate;
        maxPrice *= currencyConfig.rate;
        monthlyMaintenanceMin *= currencyConfig.rate;
        monthlyMaintenanceMax *= currencyConfig.rate;

        results = {
            mode: 'new-project',
            websiteType,
            pages,
            design,
            branding,
            features,
            content,
            hosting,
            maintenance,
            timeline,
            currency,
            estimatedCost: `${currencyConfig.symbol}${Math.round(minPrice).toLocaleString()} - ${currencyConfig.symbol}${Math.round(maxPrice).toLocaleString()}`,
            estimatedTimeline: `${Math.round(finalTime)} days`,
            monthlyMaintenance: maintenance ? `${currencyConfig.symbol}${Math.round(monthlyMaintenanceMin)} - ${currencyConfig.symbol}${Math.round(monthlyMaintenanceMax)}` : ''
        };

        document.getElementById('estimated-cost').textContent = results.estimatedCost;
        document.getElementById('estimated-timeline').textContent = results.estimatedTimeline;
        document.getElementById('maintenance-cost').textContent = results.monthlyMaintenance;
    } else {
        const websiteType = document.getElementById('original-website-type').value;
        const config = revisionConfigs[websiteType];
        const revisions = Array.from(document.querySelectorAll('input[name="revisions"]:checked')).map(r => r.value).filter(r => config.revisions.includes(r));
        const pagesToUpdate = websiteType === 'landing-page' ? 1 : parseInt(document.getElementById('pages-to-update').value) || 0;
        const itemsToUpdate = parseInt(document.getElementById('items-to-update').value) || 0;

        let minTime = 0;
        let maxTime = 0;

        revisions.forEach(revision => {
            const revConfig = revisionPrices[revision];
            let minRevTime = revConfig.minTime;
            let maxRevTime = revConfig.maxTime;

            if (revConfig.perPage) {
                minRevTime *= pagesToUpdate;
                maxRevTime *= pagesToUpdate;
            } else if (revConfig.perItem) {
                minRevTime *= itemsToUpdate;
                maxRevTime *= itemsToUpdate;
            }

            minTime += minRevTime;
            maxTime += maxRevTime;
        });

        let minDays = Math.ceil(minTime / HOURS_PER_DAY);
        let maxDays = Math.ceil(maxTime / HOURS_PER_DAY);

        let minPrice = minTime * HOURLY_RATE;
        let maxPrice = maxTime * HOURLY_RATE;

        minPrice = Math.max(minPrice, 100);
        maxPrice = Math.max(maxPrice, 200);

        let finalTime = timeline === 'rush' ? maxDays / 2 : maxDays;
        if (timeline === 'rush') {
            minPrice *= 1.25;
            maxPrice *= 1.5;
        }

        minPrice *= currencyConfig.rate;
        maxPrice *= currencyConfig.rate;

        results = {
            mode: 'revisions',
            websiteType,
            revisions,
            pagesToUpdate,
            itemsToUpdate,
            timeline,
            currency,
            estimatedCost: `${currencyConfig.symbol}${Math.round(minPrice).toLocaleString()} - ${currencyConfig.symbol}${Math.round(maxPrice).toLocaleString()}`,
            estimatedTimeline: `${Math.round(finalTime)} days`
        };

        document.getElementById('estimated-cost').textContent = results.estimatedCost;
        document.getElementById('estimated-timeline').textContent = results.estimatedTimeline;
        document.getElementById('maintenance-cost').textContent = '';
    }

    return results;
}

function saveToJson() {
    const results = calculatePrice();
    const jsonData = JSON.stringify(results, null, 2);
    const blob = new Blob([jsonData], { type: 'application/json' });
    const url = URL.createObjectURL(blob);
    const a = document.createElement('a');
    a.href = url;
    a.download = `website-pricing-${results.mode}-${Date.now()}.json`;
    document.body.appendChild(a);
    a.click();
    document.body.removeChild(a);
    URL.revokeObjectURL(url);
}

updateMode();